==> nextcloud-app-calendar-1.5.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ro.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendar",
    "Hello," : "Salut,",
    "Cheers!" : "Noroc!",
    "Recipient" : "Destinatar",
    "Too many redirects. Aborting ..." : "Prea multe redirecționări. Se abandonează ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serverul de la distanță nu ne-a dat acces la calendar (eroare HTTP {%s})",
    "Error connecting to remote server" : "Eroare la conectarea la serverul de la distanță",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Eroare la solicitarea de resurse de pe serverul de la distanță. Acest lucru ar putea fi, eventual, legat de o neconcordanţă de certificat",
    "Error requesting resource on remote server" : "Eroare la solicitarea de resurse de pe serverul de la distanță",
    "Individual" : "Individual",
    "Group" : "Grup",
    "Resource" : "Resursă",
    "Room" : "Sală",
    "Unknown" : "Necunoscut",
    "Required" : "Necesar",
    "Optional" : "Opțional",
    "Does not attend" : "Nu participă",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ești într-un fus orar necunoscut ({tz}), se revine la UTC",
    "Please create a calendar first." : "Creează un calendar mai întâi.",
    "New event" : "Eveniment nou",
    "CalDAV address for clients" : "CalDAV adresa pentru clienți",
    "Error saving WebCal-calendar" : "Eroare la salvarea calendarului WebCal",
    "WebDAV address for subscriptions" : "WebDAV adresa pentru abonamente",
    "Email has been sent." : "Email-ul a fost trimis",
    "There was an issue while sending your email." : "A aparut o eroare la transmiterea email-ului.",
    "group" : "grup",
    "Details" : "Detalii",
    "Attendees" : "Participanți",
    "Reminders" : "Mementouri",
    "Repeating" : "Ciclic",
    "When shared show full event" : "Arată tot evenimentul la partajare",
    "When shared show only busy" : "Arată doar ocupat la partajare",
    "When shared hide this event" : "Ascunde evenimentul la partajare",
    "Confirmed" : "Confirmat",
    "Tentative" : "Tentativă",
    "Cancelled" : "Anulat",
    "Please add a title." : "Adaugati un titlu.",
    "Global" : "Global",
    "None" : "Niciuna",
    "Every day" : "În fiecare zi",
    "Every week" : "În fiecare săptămână",
    "Every month" : "În fiecare lună",
    "Every year" : "În fiecare an",
    "never" : "niciodată",
    "after" : "după",
    "How about getting started by importing some calendars?" : "Cum ar fi sa incepem prin a importa calendare?",
    "At time of event" : "La începutul evenimentului",
    "5 minutes before" : "cu 5 minute înainte",
    "10 minutes before" : "cu 10 minute înainte",
    "15 minutes before" : "cu 15 minute înainte",
    "30 minutes before" : "cu 30 minute înainte",
    "1 hour before" : "cu o oră înainte",
    "2 hours before" : "cu 2 ore înainte",
    "Custom" : "Particularizat",
    "Audio" : "Audio",
    "Pop-up" : "Pop up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "ore",
    "days" : "zile",
    "week" : "săptămână",
    "before" : "înainte",
    "start" : "început",
    "end" : "sfârșit",
    "Editing reminders of unknown type not supported." : "Editarea memento-urilor de tip necunoscut nu sunt suportate.",
    "Week {number} of {year}" : "Săptămâna {number} din {year}",
    "Successfully imported" : "Importat cu succes",
    "Partially imported, 1 failure" : "Importat parțial, o eroare",
    "Partially imported, {n} failures" : "Importat parțial, {n} erori",
    "Audio alarm" : "Alarmă audio",
    "{type} {time} before the event starts" : "{type} {time} înainte de începerea evenimentului",
    "{type} {time} before the event ends" : "{type} {time} înainte de sfârșitul evenimentului",
    "{type} {time} after the event starts" : "{type} {time} după începerea evenimentului",
    "{type} {time} after the event ends" : "{type} {time} după terminarea evenimentului",
    "{type} at the event's start" : "{type} la începutul evenimentului",
    "{type} at the event's end" : "{type} la sfârșitul evenimentului",
    "{type} at {time}" : "{type} la {time}",
    "{calendar} shared by {owner}" : "{calendar} partajat de {owner}",
    "Please enter a valid WebCal-URL" : "Vă rugăm să introduceți o adresă URL WebCal validă",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Eroare severă în proxy webcal. Vă rugăm să contactați administratorul pentru mai multe informații.",
    "Title of the Event" : "Numele evenimentului",
    "All day Event" : "Toată ziua",
    "Delete" : "Șterge",
    "Cancel" : "Anulează",
    "More ..." : "Mai mult ...",
    "Create" : "Creează",
    "Update" : "Actualizare",
    "Close" : "Închide",
    "Location" : "Locație",
    "Description" : "Descriere",
    "Event status" : "Stare eveniment",
    "Visibility when sharing" : "Vizibilitate la partajare",
    "Export" : "Exportă",
    "%s has published the calendar %s" : "%s a publicat calendarul %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Am vrut să vă anunțăm că %s  a publicat calendarul {boldstart}%s{boldend}.",
    "Click here to access it" : "Click aici pentru a accesa",
    "We wanted to inform you that %s has published the calendar %s." : "Am vrut să vă anunțăm că %s a publicat calendarul  %s.",
    "Click on the link below to access it" : "Faceți clic pe link-ul de mai jos pentru a accesa",
    "Day" : "Zi",
    "Week" : "Săptămâna",
    "Month" : "Luna",
    "Today" : "Astăzi",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Anumite evenimente din acest calendar sunt invalide. Vă rugăm să verificați consola JS pentru mai multe informatii.",
    "Share Calendar" : "Partajează calendarul",
    "Shared" : "Partajat",
    "More" : "Mai mult",
    "Edit" : "Editează",
    "Link" : "Legătură",
    "iCal link" : "legătură iCal",
    "Download" : "Descarcă",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "can edit" : "poate edita",
    "Share link" : "Partajază legătură",
    "Public access" : "Access public",
    "Email link to person" : "Expediază legătura prin poșta electronică",
    "Send" : "Trimite",
    "New Calendar" : "Calendar nou",
    "Name" : "Nume",
    "New Subscription" : "Abonament nou",
    "Go back" : "Înapoi",
    "Go forward" : "Inainte",
    "Calendar does not exist" : "Calendarul nu exista",
    "Edit event" : "Modifica eveniment",
    "Delete Event" : "Șterge evenimentul",
    "Save Event" : "Salvează evenimentul",
    "Time" : "Timp",
    "Type" : "Tip",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Repetă",
    "times every" : "ori la fiecare",
    "Add" : "Adaugă",
    "Please add your email address in the personal settings in order to add attendees." : "Vă rugăm să adăugați adresa de e-mail în setările personale pentru a adăuga participanți.",
    "from" : "de la",
    "to" : "către",
    "This event's repeating rule is not supported yet." : "Regula de repetare a acestui eveniment nu este încă suportată.",
    "Support for advanced rules will be added with subsequent updates." : "Suportul pentru reguli avansate va fi adăugat în actualizări viitoare.",
    "Reset repeating rule" : "Resetează regula pentru repetare",
    "Repeat every ..." : "Se repetă la fiecare ...",
    "end repeat ..." : "sfârșit repetare ...",
    "times" : "ori",
    "Import Calendars" : "Importă calendare",
    "Import canceled" : "Import anulat",
    "Analyzing calendar" : "Se analizează calendarul",
    "The file contains objects incompatible with the selected calendar" : "Fișierul conține obiecte incompatibile cu calendarul selectat",
    "New calendar" : "Calendar nou",
    "File is empty" : "File is empty",
    "Import scheduled" : "Import programat",
    "Publish URL" : "Publică URL",
    "Settings & import" : "Setări și import",
    "Skip simple event editor" : "Sari peste editorul simplu de evenimente",
    "Show week numbers" : "Afișați numerele săptămânilor",
    "Import calendar" : "Import calendar",
    "No Calendars selected for import" : "Nu a fost selectat niciun calendar pentru import",
    "Primary CalDAV address" : "Adresă primară CalDAV",
    "iOS/OS X CalDAV address" : "Adresă iOS/OS X CalDAV"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ro.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendar",
    "%s has published the calendar »%s«" : "%sa publicat calendarul »%s«",
    "Hello," : "Salut,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vă informăm că %sa publicat calendarul »%s«.",
    "Open »%s«" : "Accesează »%s«",
    "Cheers!" : "Noroc!",
    "Recipient" : "Destinatar",
    "Too many redirects. Aborting ..." : "Prea multe redirecționări. Se abandonează ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serverul de la distanță nu ne-a dat acces la calendar (eroare HTTP {%s})",
    "Error connecting to remote server" : "Eroare la conectarea la serverul de la distanță",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Eroare la solicitarea de resurse de pe serverul de la distanță. Acest lucru ar putea fi, eventual, legat de o neconcordanţă de certificat",
    "Error requesting resource on remote server" : "Eroare la solicitarea de resurse de pe serverul de la distanță",
    "Individual" : "Individual",
    "Group" : "Grup",
    "Resource" : "Resursă",
    "Room" : "Sală",
    "Unknown" : "Necunoscut",
    "Required" : "Necesar",
    "Optional" : "Opțional",
    "Does not attend" : "Nu participă",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ești într-un fus orar necunoscut ({tz}), se revine la UTC",
    "Please create a calendar first." : "Creează un calendar mai întâi.",
    "New event" : "Eveniment nou",
    "CalDAV address for clients" : "CalDAV adresa pentru clienți",
    "Error saving WebCal-calendar" : "Eroare la salvarea calendarului WebCal",
    "WebDAV address for subscriptions" : "WebDAV adresa pentru abonamente",
    "Email has been sent." : "Email-ul a fost trimis",
    "There was an issue while sending your email." : "A aparut o eroare la transmiterea email-ului.",
    "group" : "grup",
    "Details" : "Detalii",
    "Attendees" : "Participanți",
    "Reminders" : "Mementouri",
    "Repeating" : "Ciclic",
    "When shared show full event" : "Arată tot evenimentul la partajare",
    "When shared show only busy" : "Arată doar ocupat la partajare",
    "When shared hide this event" : "Ascunde evenimentul la partajare",
    "Confirmed" : "Confirmat",
    "Tentative" : "Tentativă",
    "Cancelled" : "Anulat",
    "Please add a title." : "Adaugati un titlu.",
    "Please select a calendar." : "Vă rugăm selectați un calendar.",
    "The event can not end before it starts." : "Evenimentul nu poate înceta înainte de pornire.",
    "Global" : "Global",
    "None" : "Niciuna",
    "Every day" : "În fiecare zi",
    "Every week" : "În fiecare săptămână",
    "Every month" : "În fiecare lună",
    "Every year" : "În fiecare an",
    "never" : "niciodată",
    "after" : "după",
    "How about getting started by importing some calendars?" : "Cum ar fi sa incepem prin a importa calendare?",
    "At time of event" : "La începutul evenimentului",
    "5 minutes before" : "cu 5 minute înainte",
    "10 minutes before" : "cu 10 minute înainte",
    "15 minutes before" : "cu 15 minute înainte",
    "30 minutes before" : "cu 30 minute înainte",
    "1 hour before" : "cu o oră înainte",
    "2 hours before" : "cu 2 ore înainte",
    "Custom" : "Particularizat",
    "Audio" : "Audio",
    "Email" : "Email",
    "Pop-up" : "Pop up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "ore",
    "days" : "zile",
    "week" : "săptămână",
    "before" : "înainte",
    "start" : "început",
    "end" : "sfârșit",
    "Editing reminders of unknown type not supported." : "Editarea memento-urilor de tip necunoscut nu sunt suportate.",
    "Week {number} of {year}" : "Săptămâna {number} din {year}",
    "Successfully imported" : "Importat cu succes",
    "Partially imported, 1 failure" : "Importat parțial, o eroare",
    "Partially imported, {n} failures" : "Importat parțial, {n} erori",
    "Audio alarm" : "Alarmă audio",
    "{type} {time} before the event starts" : "{type} {time} înainte de începerea evenimentului",
    "{type} {time} before the event ends" : "{type} {time} înainte de sfârșitul evenimentului",
    "{type} {time} after the event starts" : "{type} {time} după începerea evenimentului",
    "{type} {time} after the event ends" : "{type} {time} după terminarea evenimentului",
    "{type} at the event's start" : "{type} la începutul evenimentului",
    "{type} at the event's end" : "{type} la sfârșitul evenimentului",
    "{type} at {time}" : "{type} la {time}",
    "{calendar} shared by {owner}" : "{calendar} partajat de {owner}",
    "Please enter a valid WebCal-URL" : "Vă rugăm să introduceți o adresă URL WebCal validă",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Eroare severă în proxy webcal. Vă rugăm să contactați administratorul pentru mai multe informații.",
    "Title of the Event" : "Numele evenimentului",
    "Starts" : "Începe",
    "Ends" : "Se termină",
    "All day Event" : "Toată ziua",
    "Delete" : "Șterge",
    "Cancel" : "Anulează",
    "More ..." : "Mai mult ...",
    "Create" : "Creează",
    "Update" : "Actualizare",
    "Close" : "Închide",
    "Location" : "Locație",
    "Description" : "Descriere",
    "Event status" : "Stare eveniment",
    "Visibility when sharing" : "Vizibilitate la partajare",
    "Export" : "Exportă",
    "%s has published the calendar %s" : "%s a publicat calendarul %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Am vrut să vă anunțăm că %s  a publicat calendarul {boldstart}%s{boldend}.",
    "Click here to access it" : "Click aici pentru a accesa",
    "We wanted to inform you that %s has published the calendar %s." : "Am vrut să vă anunțăm că %s a publicat calendarul  %s.",
    "Click on the link below to access it" : "Faceți clic pe link-ul de mai jos pentru a accesa",
    "Day" : "Zi",
    "Week" : "Săptămâna",
    "Month" : "Luna",
    "Today" : "Astăzi",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Anumite evenimente din acest calendar sunt invalide. Vă rugăm să verificați consola JS pentru mai multe informatii.",
    "Share Calendar" : "Partajează calendarul",
    "Shared" : "Partajat",
    "More" : "Mai mult",
    "Edit" : "Editează",
    "Link" : "Legătură",
    "iCal link" : "legătură iCal",
    "Download" : "Descarcă",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "can edit" : "poate edita",
    "Share link" : "Partajază legătură",
    "Public access" : "Access public",
    "Email link to person" : "Expediază legătura prin poșta electronică",
    "Send" : "Trimite",
    "New Calendar" : "Calendar nou",
    "Name" : "Nume",
    "New Subscription" : "Abonament nou",
    "Go back" : "Înapoi",
    "Go forward" : "Inainte",
    "Calendar does not exist" : "Calendarul nu exista",
    "Maybe you got a wrong link or the calendar was unshared?" : "Linkul e greșit sau calendarul nu a fost partajat?",
    "Edit event" : "Modifica eveniment",
    "Delete Event" : "Șterge evenimentul",
    "Save Event" : "Salvează evenimentul",
    "Time" : "Timp",
    "Type" : "Tip",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Repetă",
    "times every" : "ori la fiecare",
    "Add" : "Adaugă",
    "Email address of attendee" : "Adresa de email a participantului",
    "Please add your email address in the personal settings in order to add attendees." : "Vă rugăm să adăugați adresa de e-mail în setările personale pentru a adăuga participanți.",
    "from" : "de la",
    "to" : "către",
    "This event's repeating rule is not supported yet." : "Regula de repetare a acestui eveniment nu este încă suportată.",
    "Support for advanced rules will be added with subsequent updates." : "Suportul pentru reguli avansate va fi adăugat în actualizări viitoare.",
    "Reset repeating rule" : "Resetează regula pentru repetare",
    "Repeat every ..." : "Se repetă la fiecare ...",
    "end repeat ..." : "sfârșit repetare ...",
    "times" : "ori",
    "Import Calendars" : "Importă calendare",
    "Import canceled" : "Import anulat",
    "Analyzing calendar" : "Se analizează calendarul",
    "The file contains objects incompatible with the selected calendar" : "Fișierul conține obiecte incompatibile cu calendarul selectat",
    "New calendar" : "Calendar nou",
    "File is empty" : "File is empty",
    "Import scheduled" : "Import programat",
    "%s shared the calendar <strong>%s</strong> with you" : "%sa partajat calendarul <strong>%s</strong> cu tine",
    "Embed" : "Integra",
    "Iframe to integrate" : "Iframe de inserat",
    "Publish URL" : "Publică URL",
    "Settings & import" : "Setări și import",
    "Skip simple event editor" : "Sari peste editorul simplu de evenimente",
    "Show week numbers" : "Afișați numerele săptămânilor",
    "Import calendar" : "Import calendar",
    "No Calendars selected for import" : "Nu a fost selectat niciun calendar pentru import",
    "Primary CalDAV address" : "Adresă primară CalDAV",
    "iOS/OS X CalDAV address" : "Adresă iOS/OS X CalDAV",
    "Subscribe" : "Abonare"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
